==> estateplat-common-1.2.3-20180109.015111-8-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/LsFcjyClfMmhtQttk.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
 * @version V1.0, 2017/9/21
 * @description
 */
@Table(name = "ls_fcjy_clf_mmht_qttk")
public class LsFcjyClfMmhtQttk implements InsertVo {
    @Id
    private String id;//主键
    private String htid;//合同id
    private String qtyd;//其他约定
    private String wyzr;//违约责任
    private String xyjcfs;//协议解除方式
    private String xyjcqtsm;//协议解除其他说明
    private String zyjjfs;//争议解决方式

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getQtyd() {
        return qtyd;
    }

    public void setQtyd(String qtyd) {
        this.qtyd = qtyd;
    }

    public String getWyzr() {
        return wyzr;
    }

    public void setWyzr(String wyzr) {
        this.wyzr = wyzr;
    }

    public String getXyjcfs() {
        return xyjcfs;
    }

    public void setXyjcfs(String xyjcfs) {
        this.xyjcfs = xyjcfs;
    }

    public String getXyjcqtsm() {
        return xyjcqtsm;
    }

    public void setXyjcqtsm(String xyjcqtsm) {
        this.xyjcqtsm = xyjcqtsm;
    }

    public String getZyjjfs() {
        return zyjjfs;
    }

    public void setZyjjfs(String zyjjfs) {
        this.zyjjfs = zyjjfs;
    }
}

==> estateplat-common-1.2.3-20180202.065337-24-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/LsFcjyClfMmhtQttk.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
 * @version V1.0, 2017/9/21
 * @description
 */
@Table(name = "ls_fcjy_clf_mmht_qttk")
public class LsFcjyClfMmhtQttk implements InsertVo {
    @Id
    private String id;//主键
    private String htid;//合同id
    private String qtyd;//其他约定
    private String wyzr;//违约责任
    private String xyjcfs;//协议解除方式
    private String xyjcqtsm;//协议解除其他说明
    private String zyjjfs;//争议解决方式
    private Integer wyjzfqx;//违约金支付期限
    private Double wyjje;//违约金金额
    private Double wyjbl;//违约金比例
    private Double byxzwyj;//不予协助违约金

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getQtyd() {
        return qtyd;
    }

    public void setQtyd(String qtyd) {
        this.qtyd = qtyd;
    }

    public String getWyzr() {
        return wyzr;
    }

    public void setWyzr(String wyzr) {
        this.wyzr = wyzr;
    }

    public String getXyjcfs() {
        return xyjcfs;
    }

    public void setXyjcfs(String xyjcfs) {
        this.xyjcfs = xyjcfs;
    }

    public String getXyjcqtsm() {
        return xyjcqtsm;
    }

    public void setXyjcqtsm(String xyjcqtsm) {
        this.xyjcqtsm = xyjcqtsm;
    }

    public String getZyjjfs() {
        return zyjjfs;
    }

    public void setZyjjfs(String zyjjfs) {
        this.zyjjfs = zyjjfs;
    }

    public Integer getWyjzfqx() {
        return wyjzfqx;
    }

    public void setWyjzfqx(Integer wyjzfqx) {
        this.wyjzfqx = wyjzfqx;
    }

    public Double getWyjje() {
        return wyjje;
    }

    public void setWyjje(Double wyjje) {
        this.wyjje = wyjje;
    }

    public Double getWyjbl() {
        return wyjbl;
    }

    public void setWyjbl(Double wyjbl) {
        this.wyjbl = wyjbl;
    }

    public Double getByxzwyj() {
        return byxzwyj;
    }

    public void setByxzwyj(Double byxzwyj) {
        this.byxzwyj = byxzwyj;
    }
}
